@@ -1,13 +1,23 @@
-/* A symbol table. */
+/*
+  A symbol table.
+  Copyright (C) 2005 The MITRE Corporation
+
+  Author: John D. Ramsdell
+
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+*/
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <obstack.h>
 #include <search.h>
-#include "xmalloc.h"
-#include "symbol.h"
-#include "intern.h"
+#include <slat/xmalloc.h>
+#include <slat/symbol.h>
+#include <slat/intern.h>
 
 /* Initial hash table size */
 #define HSIZE (1 << 13)
@@ -20,14 +30,14 @@
 static struct obstack stack[1];
 
 void
-intern_init()
+intern_init(void)
 {
   hcreate(HSIZE);
   obstack_init(stack);
 }
 
 void
-intern_free()
+intern_free(void)
 {
   obstack_free(stack, 0);
 }
@@ -45,7 +55,7 @@ intern(const char *s)
     ep = hsearch(e, ENTER);
   }
   if (!ep) {
-    fprintf(stderr, 
+    fprintf(stderr,
 	    "In symbol table, malloc failed during hash table entry\n");
     exit(1);
   }
