@@ -1,10 +1,23 @@
+/*
+  Converts LTS and diagrams into pretty printed SMV.
+  Copyright (C) 2005 The MITRE Corporation
+
+  Author: John D. Ramsdell
+
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+*/
+
 #include <stdio.h>
 #include <stdarg.h>
 #include <string.h>
 #include <setjmp.h>
-#include "pprint.h"
-#include "symbol.h"
-#include "formula.h"
+#include <slat/pprint.h>
+#include <slat/symbol.h>
+#include <slat/formula.h>
+#include "gensmv.h"
 
 // Pretty printing parameters
 
@@ -18,7 +31,7 @@ static jmp_buf env;
 // Call leave to throw an exception
 
 static void
-leave()
+leave(void)
 {
   longjmp(env, 1);
 }
@@ -393,6 +406,8 @@ ptran(tran_t tran, int neg, int level, pretty_t next)
       p = pstring("( ", p);
     return pblock(INDENT, p, next);
   }
+  else if (level < tran_prec && assoc(tran) != NON_ASSOC)
+    return pblock(0, ptran(tran, neg, tran_prec, 0), next);
   else {
     switch (tran_type(tran)) {
     case TRAN_TRUE:
