@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875c.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,36 +30,28 @@
       know about them.  */
    enum yytokentype {
      UNUSED = 258,
-     IDENTIFIER = 259,
-     CLASS = 260,
-     COMMON = 261,
-     ALIAS = 262,
-     SENSITIVITY = 263,
-     DOMINANCE = 264,
-     CATEGORY = 265,
-     LEVEL = 266
+     CLASS = 259,
+     COMMON = 260,
+     IDENTIFIER = 261
    };
 #endif
 #define UNUSED 258
-#define IDENTIFIER 259
-#define CLASS 260
-#define COMMON 261
-#define ALIAS 262
-#define SENSITIVITY 263
-#define DOMINANCE 264
-#define CATEGORY 265
-#define LEVEL 266
+#define CLASS 259
+#define COMMON 260
+#define IDENTIFIER 261
 
 
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 44 "parser.y"
+#line 27 "parser.y"
 typedef union YYSTYPE {
-  symbol_t id;
+  int common;			/* Zero if a class was found */
+  flow_dir_t flow;		/* Created by the dir non-terminal */
+  char *id;
 } YYSTYPE;
-/* Line 1275 of yacc.c.  */
-#line 63 "parser.h"
+/* Line 1318 of yacc.c.  */
+#line 55 "parser.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
